package main

import (
	"database/sql"

	migration "bitbucket.org/prmunty/util/dbmigration/db"
	_ "github.com/mattn/go-sqlite3"
)

func main() {
	const version float64 = 3.0

	migration.Migrate(version, func(tx *sql.Tx) (err error) {
		return migration.DoUntilErr(tx,
			AddFreezeScreenSelections,
			RemoveFreezeScreenSelections,
			FixFreezeScreenSelections,
		)
	})

}


func AddFreezeScreenSelections(tx *sql.Tx) error {
	freezeIDs := []int{507,3638,4330,4347}

	for _, freezeID := range freezeIDs {
		if _, err := tx.Exec(
			`INSERT OR IGNORE INTO freeze_data_compressor(freeze_id, selected) VALUES( ?, 0 )`,
			freezeID,
		); err != nil {
			return err
		}
	}

	return nil
}

func RemoveFreezeScreenSelections(tx *sql.Tx) error {
	freezeIDs := []int{12,776,2162,2195}

	for _, freezeID := range freezeIDs {
		if _, err := tx.Exec(
			`DELETE FROM freeze_data_compressor WHERE freeze_id = ?`,
			freezeID,
		); err != nil {
			return err
		}
	}

	return nil
}

func FixFreezeScreenSelections(tx *sql.Tx) error {
	if _, err := tx.Exec(
		`UPDATE freeze_data_compressor SET selected = 1`,
	); err != nil {
		return err
	}

	return nil
}
